# sabotage

[![License](https://img.shields.io/github/license/nikitanovosibirsk/sabotage.svg)](https://github.com/nikitanovosibirsk/sabotage)
[![PyPI](https://img.shields.io/pypi/v/sabotage.svg)](https://pypi.python.org/pypi/sabotage)
[![Python Version](https://img.shields.io/pypi/pyversions/sabotage.svg)](https://pypi.python.org/pypi/sabotage)

## Installation

```bash
pip3 install sabotage
```
